@@ -12,12 +12,13 @@
 # language governing permissions and limitations under the License.
 
 import logging
+from logging import NullHandler
 
 from boto3.compat import _warn_deprecated_python
 from boto3.session import Session
 
 __author__ = 'Amazon Web Services'
-__version__ = '1.36.12'
+__version__ = '1.40.24'
 
 
 # The default Boto3 session; autoloaded when needed.
@@ -101,11 +102,6 @@ def resource(*args, **kwargs):
     return _get_default_session().resource(*args, **kwargs)
 
 
-# Set up logging to ``/dev/null`` like a library is supposed to.
+# Set up do-nothing logging like a library is supposed to.
 # https://docs.python.org/3.3/howto/logging.html#configuring-logging-for-a-library
-class NullHandler(logging.Handler):
-    def emit(self, record):
-        pass
-
-
 logging.getLogger('boto3').addHandler(NullHandler())
